@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) Jarkko Hietaniemi, 1998. All Rights Reserved.
+Copyright (C) Jarkko Hietaniemi, 1998-1999. All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of either:
@@ -63,8 +63,8 @@ typedef	int		apse_bool_t;
 
 typedef struct apse_s {
     apse_size_t		pattern_size;
-
     apse_vec_t*		pattern_mask;
+
     apse_vec_t*		case_mask;
     apse_vec_t*		fold_mask;
 
@@ -74,6 +74,7 @@ typedef struct apse_s {
     apse_size_t		edit_insertions;
     apse_size_t		edit_deletions;
     apse_size_t		edit_substitutions;
+    apse_bool_t		use_minimal_distance;
 
     apse_size_t		bitvectors_in_state;
     apse_size_t		bytes_in_state;
@@ -83,6 +84,8 @@ typedef struct apse_s {
     unsigned char*	text;
     apse_size_t		text_size;
     apse_size_t		text_position;
+    apse_size_t		text_initial_position;
+    apse_size_t		text_final_position;
 
     apse_vec_t*		state;
     apse_vec_t*		prev_state;
@@ -123,10 +126,10 @@ apse_bool_t apse_match_next(apse_t*		ap,
 
 apse_ssize_t apse_index(apse_t*		ap,
 			unsigned char*	text,
-			apse_size_t text_size);
+			apse_size_t 	text_size);
 apse_ssize_t apse_index_next(apse_t*		ap,
 			     unsigned char*	text,
-			     apse_size_t text_size);
+			     apse_size_t 	text_size);
 
 apse_bool_t apse_slice(apse_t*		ap,
 		       unsigned char*	text,
@@ -146,6 +149,17 @@ apse_bool_t apse_set_pattern(apse_t*		ap,
 			     apse_size_t	pattern_size);
 apse_bool_t apse_set_edit_distance(apse_t *ap, apse_size_t edit_distance);
 apse_size_t apse_get_edit_distance(apse_t *ap);
+apse_bool_t apse_set_minimal_distance(apse_t* ap, apse_bool_t minimal);
+apse_bool_t apse_get_minimal_distance(apse_t* ap);
+apse_bool_t apse_set_text_position(apse_t *ap,
+				   apse_size_t text_position);
+apse_size_t apse_get_text_position(apse_t *ap);
+apse_bool_t apse_set_text_initial_position(apse_t *ap,
+					   apse_size_t text_initial_position);
+apse_size_t apse_get_text_initial_position(apse_t *ap);
+apse_bool_t apse_set_text_final_position(apse_t *ap,
+					   apse_size_t text_final_position);
+apse_size_t apse_get_text_final_position(apse_t *ap);
 
 apse_bool_t apse_set_insertions(apse_t *ap, apse_size_t insertions);
 apse_bool_t apse_set_deletions(apse_t *ap, apse_size_t deletions);
